@@ -5,7 +5,7 @@ DIR=jetty-$2
 TAG=$(echo jetty-$2 | sed 's,~alpha,-alpha-,')
 
 svn export http://svn.codehaus.org/jetty/jetty/tags/$TAG/ $DIR
-rm -r $DIR/modules/jsp-api-2.0
+rm -r $DIR/modules/jsp-api-2.*
 rm -r $DIR/extras/win32service
 rm -r $DIR/contrib/cometd
 rm -r $DIR/contrib/rpms
